@@ -12,6 +12,7 @@
 #define KNEWPASSWORDDIALOG_H
 
 #include <QDialog>
+#include <memory>
 
 #include <kwidgetsaddons_export.h>
 
@@ -53,8 +54,7 @@ class QWidget;
  * @author Geert Jansen <jansen@kde.org>
  * @author Olivier Goffart <ogoffart@kde.org>
  */
-class KWIDGETSADDONS_EXPORT KNewPasswordDialog
-    : public QDialog
+class KWIDGETSADDONS_EXPORT KNewPasswordDialog : public QDialog
 {
     Q_OBJECT
 
@@ -231,7 +231,6 @@ public:
     void accept() override;
 
 protected:
-
     /**
      * Virtual function that can be overridden to provide password
      * checking in derived classes. It should return @p true if the
@@ -256,11 +255,9 @@ Q_SIGNALS:
     void newPassword(const QString &password);
 
 private:
-    class KNewPasswordDialogPrivate;
-    KNewPasswordDialogPrivate *const d;
+    std::unique_ptr<class KNewPasswordDialogPrivate> const d;
 
     Q_PRIVATE_SLOT(d, void _k_passwordStatusChanged())
 };
 
 #endif // KNEWPASSWORDDIALOG_H
-
